==> am_mod_blg_0_4.zip: am_mod_blg_0_4/components/blg/language/1/barnraiser_01/item.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once('inc/blg_common.inc.php');

// HEADER
$lang['hdr_tags'] = 							"tags";
$lang['hdr_my_participation'] = 				"my participation";
$lang['hdr_blog'] = 							"blog";
$lang['hdr_blog_entry'] = 						"blog entry";
$lang['hdr_entries'] = 							"latest entries";


// SUB
$lang['sub_tag_ok'] = 							"OK";
$lang['sub_tag_delete'] = 						"DEL";


//A HREF TAGS (links)
$lang['href_edit_entry'] = 						"edit this entry";
$lang['href_respect'] = 						"respect";
$lang['href_list'] = 							"list all";
$lang['href_join'] = 							"join";
$lang['href_edit_blog'] = 						"edit blog";
$lang['href_create_entry'] = 					"create entry";


// BODY
$lang['txt_role'] = 							"role";
$lang['txt_status']	=							"status";
$lang['txt_bookmarked'] = 						"bookmarked in this set";
$lang['txt_relevent_summary'] = 				"SYS_KEYWORD_PERCENTAGE% of SYS_KEYWORD_TOTAL people who have voted think this entry is relevent";
$lang['txt_accurate_summary'] = 				"SYS_KEYWORD_PERCENTAGE% of SYS_KEYWORD_TOTAL people who have voted think this entry is accurate";
$lang['txt_tags'] = 							"tags";
$lang['txt_participate_first'] = 				"you need to participate in order to leave comments";
$lang['txt_alt_remove_bookmark'] = 				"remove bookmark";
$lang['txt_title_remove_bookmark'] = 			"remove bookmark from this entry";
$lang['txt_alt_bookmark'] = 					"bookmark";
$lang['txt_title_add_bookmark'] = 					"bookmark this entry";
$lang['txt_alt_track'] = 						"track";
$lang['txt_title_add_track'] = 						"track this entry";
$lang['txt_alt_remove_recommendation'] = 		"remove recommendation";
$lang['txt_title_remove_recommendation'] = 		"remove recommendation from this entry";
$lang['txt_alt_add_recommendation'] = 			"recommend";
$lang['txt_title_add_recommendation'] = 		"recommend this entry";
$lang['txt_relevent'] = 						"relevent?";
$lang['txt_accurate'] = 						"accurate?";

$lang['txt_title_not_relevent'] = 				"you have voted this entry as not relevent";
$lang['txt_title_set_not_relevent'] = 			"this entry is not relevent";
$lang['txt_alt_not_relevent'] = 				"not relevent";
$lang['txt_title_relevent'] = 					"you have voted this entry as relevent";
$lang['txt_title_set_relevent'] = 				"this entry is relevent";
$lang['txt_alt_relevent'] = 					"relevent";

$lang['txt_title_not_accurate'] = 				"you have voted this entry as not accurate";
$lang['txt_title_set_not_accurate'] = 			"this entry is not accurate";
$lang['txt_alt_not_accurate'] = 				"not accurate";
$lang['txt_title_accurate'] = 					"you have voted this entry as accurate";
$lang['txt_title_set_accurate'] = 				"this entry is accurate";
$lang['txt_alt_accurate'] = 					"accurate";

$lang['txt_title_rss'] = 						"really simple syndication feed";
$lang['txt_alt_rss'] = 							"RSS";

$lang['txt_no_entries'] = 						"There are no entries for this blog yet.";
$lang['txt_blogroll'] = 						"blogroll";
$lang['txt_authors'] = 							"authors";

$lang['txt_alt_add_bookmark'] = 					"bookmark";
$lang['txt_alt_add_track'] = 						"track";

?>

==> am_mod_blg_0_5.zip: am_mod_blg_0_5/components/blg/language/1/barnraiser_01/item.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once('inc/blg_common.inc.php');

// HEADER
$lang['hdr_tags'] = 							"tags";
$lang['hdr_my_participation'] = 				"my participation";
$lang['hdr_blog'] = 							"blog";
$lang['hdr_blog_entry'] = 						"blog entry";
$lang['hdr_entries'] = 							"latest entries";


// SUB
$lang['sub_tag_ok'] = 							"OK";
$lang['sub_tag_delete'] = 						"DEL";


//A HREF TAGS (links)
$lang['href_edit_entry'] = 						"edit this entry";
$lang['href_respect'] = 						"respect";
$lang['href_list'] = 							"list all";
$lang['href_join'] = 							"join";
$lang['href_edit_blog'] = 						"edit blog";
$lang['href_create_entry'] = 					"create entry";
$lang['href_set_to_live'] = 					"set as live";


// BODY
$lang['txt_role'] = 							"role";
$lang['txt_status']	=							"status";
$lang['txt_bookmarked'] = 						"bookmarked in this set";
$lang['txt_relevent_summary'] = 				"SYS_KEYWORD_PERCENTAGE% of SYS_KEYWORD_TOTAL people who have voted think this entry is relevent";
$lang['txt_accurate_summary'] = 				"SYS_KEYWORD_PERCENTAGE% of SYS_KEYWORD_TOTAL people who have voted think this entry is accurate";
$lang['txt_tags'] = 							"tags";
$lang['txt_participate_first'] = 				"you need to participate in order to leave comments";
$lang['txt_alt_remove_bookmark'] = 				"remove bookmark";
$lang['txt_title_remove_bookmark'] = 			"remove bookmark from this entry";
$lang['txt_alt_bookmark'] = 					"bookmark";
$lang['txt_title_add_bookmark'] = 					"bookmark this entry";
$lang['txt_alt_track'] = 						"track";
$lang['txt_title_add_track'] = 						"track this entry";
$lang['txt_alt_remove_recommendation'] = 		"remove recommendation";
$lang['txt_title_remove_recommendation'] = 		"remove recommendation from this entry";
$lang['txt_alt_add_recommendation'] = 			"recommend";
$lang['txt_title_add_recommendation'] = 		"recommend this entry";
$lang['txt_relevent'] = 						"relevent?";
$lang['txt_accurate'] = 						"accurate?";

$lang['txt_title_not_relevent'] = 				"you have voted this entry as not relevent";
$lang['txt_title_set_not_relevent'] = 			"this entry is not relevent";
$lang['txt_alt_not_relevent'] = 				"not relevent";
$lang['txt_title_relevent'] = 					"you have voted this entry as relevent";
$lang['txt_title_set_relevent'] = 				"this entry is relevent";
$lang['txt_alt_relevent'] = 					"relevent";

$lang['txt_title_not_accurate'] = 				"you have voted this entry as not accurate";
$lang['txt_title_set_not_accurate'] = 			"this entry is not accurate";
$lang['txt_alt_not_accurate'] = 				"not accurate";
$lang['txt_title_accurate'] = 					"you have voted this entry as accurate";
$lang['txt_title_set_accurate'] = 				"this entry is accurate";
$lang['txt_alt_accurate'] = 					"accurate";

$lang['txt_title_rss'] = 						"really simple syndication feed";
$lang['txt_alt_rss'] = 							"RSS";

$lang['txt_no_entries'] = 						"There are no entries for this blog yet.";
$lang['txt_blogroll'] = 						"blogroll";
$lang['txt_authors'] = 							"authors";

$lang['txt_alt_add_bookmark'] = 					"bookmark";
$lang['txt_alt_add_track'] = 						"track";

$lang['txt_status_not_live'] = 					"This blog is not live which means only you can see it. To submit it for review please send a message to the site maintainer (see the structure page for a list of maintainers).";
$lang['txt_status_not_live_owner_set'] = 		"This blog is not live which means only you can see it. To make it live click the button below.";

?>
